@@ -69,18 +69,22 @@ public:
 
     void setExcepMarker() { excep_data_marker = 1; };
     void setExceptionNum(uint32_t excepNum) { exception_number = excepNum; };
-
-
     void setTraceOnReason(const trace_on_reason_t reason);
+    void setUnSyncEOTReason(const unsync_info_t reason);
+    void setTransactionType(const trace_memtrans_t trans) { mem_trans = trans; };
 
     void setAddrRange(const ocsd_vaddr_t  st_addr, const ocsd_vaddr_t en_addr, const int num_instr = 1);
     void setLastInstrInfo(const bool exec, const ocsd_instr_type last_i_type, const ocsd_instr_subtype last_i_subtype, const uint8_t size);
-    void setAddrStart(const ocsd_vaddr_t  st_addr) { this->st_addr = st_addr; };
+    void setAddrStart(const ocsd_vaddr_t st_addr) { this->st_addr = st_addr; };
     void setLastInstrCond(const int is_cond) { this->last_instr_cond = is_cond; };
 
     void setSWTInfo(const ocsd_swt_info_t swt_info) { sw_trace_info = swt_info; };
     void setExtendedDataPtr(const void *data_ptr);
 
+    void setITEInfo(const trace_sw_ite_t sw_instrumentation) { sw_ite = sw_instrumentation; };
+
+    void setSyncMarker(const trace_marker_payload_t &marker);
+
 // stringize the element
 
     virtual void toString(std::string &str) const;
@@ -94,7 +98,8 @@ public:
     // return current context
     const ocsd_pe_context &getContext() const {  return context; };
 
-    
+    void copyPersistentData(const OcsdTraceElement &src);
+
 private:
     void printSWInfoPkt(std::ostringstream &oss) const;
     void clearPerPktData(); //!< clear flags that indicate validity / have values on a per packet basis
@@ -171,8 +176,8 @@ inline void OcsdTraceElement::init()
 
 inline void OcsdTraceElement::clearPerPktData()
 {
-    flag_bits = 0; // union with trace_on_reason / trace_event
-
+    flag_bits = 0;          // bit-field with various flags.
+    exception_number = 0;   // union with trace_on_reason / trace_event
     ptr_extended_data = 0;  // extended data pointer
 }
 
@@ -181,6 +186,11 @@ inline void OcsdTraceElement::setTraceOnReason(const trace_on_reason_t reason)
     trace_on_reason = reason;
 }
 
+inline void OcsdTraceElement::setUnSyncEOTReason(const unsync_info_t reason)
+{
+    unsync_eot_info = reason;
+}
+
 inline void OcsdTraceElement::setISA(const ocsd_isa isa_update)
 {
     isa = isa_update;
@@ -201,6 +211,17 @@ inline void OcsdTraceElement::setExtendedDataPtr(const void *data_ptr)
     ptr_extended_data = data_ptr;
 }
 
+inline void OcsdTraceElement::setSyncMarker(const trace_marker_payload_t &marker)
+{
+    sync_marker = marker;
+}
+
+// set persistent data between output packets.
+inline void OcsdTraceElement::copyPersistentData(const OcsdTraceElement &src)
+{
+    isa = src.isa;
+    context = src.context;
+}
 
 /** @}*/
 
