@@ -564,12 +564,19 @@ ocsd_err_t TrcPktDecodeEtmV4I::decodePacket()
         }
         break;
 
-    /*** presently unsupported packets ***/
-    /* ETE commit window - not supported in current ETE versions - blocked by packet processor */
-    case ETE_PKT_I_COMMIT_WIN_MV:
-        err = OCSD_ERR_UNSUPP_DECODE_PKT;
-        err = handlePacketSeqErr(err, m_index_curr_pkt, "ETE Commit Window Move, unsupported packet type.");
+        /* PE Instrumentation packet */
+    case ETE_PKT_I_ITE:
+        {
+            trace_sw_ite_t ite_pkt;
+
+            ite_pkt.el = m_curr_packet_in->getITE_EL();
+            ite_pkt.value = m_curr_packet_in->getITE_value();
+            if (m_P0_stack.createITEElem(m_curr_packet_in->getType(), m_index_curr_pkt, ite_pkt) == 0)
+                bAllocErr = true;
+        }
         break;
+
+    /*** presently unsupported packets ***/
         /* conditional instruction tracing */
     case ETM4_PKT_I_COND_FLUSH:
     case ETM4_PKT_I_COND_I_F1:
@@ -854,6 +861,10 @@ ocsd_err_t TrcPktDecodeEtmV4I::commitElements()
             case P0_TRANS_TRACE_INIT:
                 err = processTransElem(pElem);
                 break;
+
+            case P0_ITE:
+                err = processITEElem(pElem);
+                break;
             }
 
             if(bPopElem)
@@ -957,6 +968,10 @@ ocsd_err_t TrcPktDecodeEtmV4I::commitElemOnEOT()
         case P0_MARKER:
             err = processMarkerElem(pElem);
             break;
+
+        case P0_ITE:
+            err = processITEElem(pElem);
+            break;
         }
         m_P0_stack.delete_back();
     }
@@ -1013,6 +1028,7 @@ ocsd_err_t TrcPktDecodeEtmV4I::cancelElements()
                     case P0_CC:
                     case P0_TS_CC:
                     case P0_MARKER:
+                    case P0_ITE:
                         m_P0_stack.pop_front(false);
                         temp.push_back(pElem);
                         break;
@@ -1114,6 +1130,8 @@ ocsd_err_t TrcPktDecodeEtmV4I::discardElements()
         pElem = m_P0_stack.back();
         if (pElem->getP0Type() == P0_MARKER)
             err = processMarkerElem(pElem);
+        else if (pElem->getP0Type() == P0_MARKER)
+            err = processITEElem(pElem);
         else
             err = processTS_CC_EventElem(pElem);
         m_P0_stack.delete_back();
@@ -1206,6 +1224,18 @@ ocsd_err_t TrcPktDecodeEtmV4I::processTransElem(TrcStackElem *pElem)
     return err;
 }
 
+ocsd_err_t TrcPktDecodeEtmV4I::processITEElem(TrcStackElem *pElem)
+{
+    ocsd_err_t err = OCSD_OK;
+    TrcStackElemITE *pITEElem = dynamic_cast<TrcStackElemITE *>(pElem);
+
+    err = m_out_elem.addElemType(pElem->getRootIndex(), OCSD_GEN_TRC_ELEM_INSTRUMENTATION);
+    if (!err) {
+        outElem().setITEInfo(pITEElem->getITE());
+    }
+    return err;
+}
+
 ocsd_err_t TrcPktDecodeEtmV4I::addElemCC(TrcStackElemParam *pParamElem)
 {
     ocsd_err_t err = OCSD_OK;
